// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// %                                                               %
// %   IsoWood Include File version 0.3                            %
// %                                                               %
// %   iw_ex_03.pov - Sample File                                  %
// %                                                               %
// %   written August 2003                                         %
// %   by Christoph Hormann <chris_hormann@gmx.de>                 %
// %   newest version can be found at                              %
// %   http://www.tu-bs.de/~y0013390/iso_wood.html                 %
// %                                                               %
// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//
// -w800 -h600 +a0.3
// -w320 -h240 +a0.3

#version 3.5;

// ----------------------------------------

#declare show_Parquet=true;
#declare show_Pot=true;
#declare show_Planks=true;
#declare show_Cylinders=true;
#declare show_Spheres=true;

#declare use_Area_Light=true;

// ----------------------------------------

#declare IW_Quality = 2;
#declare IW_ISOmaxgrad = 5.2;
#declare IW_ISOmax_trace = 2;

#include "functions.inc"
#include "isowood3.inc"
#include "iw_textures.inc"

global_settings {
  assumed_gamma 1.0
  max_trace_level 10
}

// ----------------------------------------


camera {
  location  <2.2, -4.5, 3.0>
  direction y
  sky       z
  up        z
  right     x*(image_width/image_height)
  look_at   <0.0, 0.0, 0.0>
  angle 24
}


light_source {
  <2500, 3000, 2100>
  color rgb <2.2, 1.8, 1.75>
  #if (use_Area_Light)
    area_light 130*x 130*y  2,2 jitter orient circular
    adaptive 1
  #end
}

sky_sphere {
  pigment {
    gradient z
    color_map {
      [0.0 rgb <0.6,0.7,1.0>]
      [0.2 rgb <0.2,0.3,0.9>]
    }
  }
}

// ----------------------------------------


plane {
  z, 0

  texture {
    pigment { color rgb 1.7 }
    finish { ambient <0.45,0.55,1.0>*0.05 diffuse 0.6 }
  }

  translate -0.9*z
}

// ----------------------------------------

#declare Fin_T=
  finish {
    ambient <0.45,0.55,1.0>*0.05
    diffuse 0.55
    specular 0.22
  }

#declare Fin_T2=
  finish {
    ambient <0.45,0.55,1.0>*0.04
    diffuse 0.55
    specular 0.22
  }

#declare Fin_T3=
  finish {
    ambient <0.45,0.55,1.0>*0.03
    diffuse 0.45
    specular 0.3
  }

#declare Fin_R=
  finish {
    ambient <0.45,0.55,1.0>*0.05
    diffuse 0.55
    specular 0.3
    reflection 0.1
  }


// ====================================================

#if (show_Parquet)     //===== parquet floot =====

  #declare P_Parquet=
    pigment {
      P_IW_07
      scale 0.3
    }


  object {
    IW_Parquet_A (
      343,
      <0, 0>, <8, 8>,
      0.5, 2,
      0.5,
      3, 1,
      0.008, 0.003,
      0.0025, 0.008,
      pigment { P_Parquet },
      Fin_T2,
      No_Normal,
      texture {
        pigment { P_IW_07 color_map { CM_IW_01 } scale 0.3 }
        finish { Fin_T2 }
      },
      1,
      22
    )

    translate <-4, -4, 0.0>
  }

#else

  box {
    <-4, -4, -1.0>,
    < 4,  4, 0.0>
    texture {
      pigment { P_IW_07 color_map { CM_IW_01 } scale 0.9 }
      finish { Fin_T2 }
    }
  }

#end

// ====================================================

#if (show_Pot)         //===== custom shape (pot) =====

  #declare P_IW_XX =
    pigment {
      wood
      warp {
        turbulence <0.06, 0.06, 0.5>*1.9
        octaves 6
        lambda 2.2
        omega 0.53
      }
      scale  <0.02, 0.02, 0.4>
    }

  difference {
    object {
      IW_CylinderR (
        74,
        1.2, 4,
        1.2,0.12,
        0.006,
        pigment { P_IW_XX color_map { CM_IW_12 } scale 1.0 },
        Fin_T,
        No_Normal
        function {
          sin(z*1.45)*0.3
        },
        0.31
      )
    }
    object {
      IW_CylinderR (
        0,
        1.2, 4.1,
        0.4,0.05,
        0.006,
        pigment { P_IW_XX color_map { CM_IW_12 } scale 1.0 },
        Fin_T,
        No_Normal
        function {
          sin(z*1.45)*0.3 - 0.08
        },
        0.31
      )
    }

    scale 0.2
    translate <-0.2, -0.35, 0.002>
  }

#end

// ====================================================

#if (show_Spheres)

  object {
    IW_Shape (
      674,
      function { f_sphere(x, y, z, 0.6) }
      -0.62, 0.62,
      20,0.5,
      0.002,
      pigment { P_IW_08 color_map { CM_IW_12 } scale 0.85 },
      Fin_T,
      No_Normal
    )
    translate <-0.7, -2.3, 0.6>
  }

  object {
    IW_Shape (
      556,
      function { f_sphere(x, y, z, 0.16) }
      -0.17, 0.17,
      20,0.5,
      0.0005,
      pigment { P_IW_05 color_map { CM_IW_19 } scale 0.72 },
      Fin_R,
      No_Normal
    )
    translate <-0.05, -1.18, 0.16>
  }

#end

// ====================================================

#if (show_Planks)

  object {
    IW_Plank_Round_CutE (
      6223,
      0.3, 1.6, 2,
      2, 6.5,
      0.03,
      0.003, 0.0045,
      pigment { P_IW_07 color_map { CM_IW_23 } scale 2.0 } ,
      Fin_T,
      No_Normal,
      2
    )

    scale 0.6
    rotate 90*y
    rotate 90*z
    translate <0.4, 0.3, 0.3*0.6>
  }

  object {
    IW_Plank_DRound (
      99623,
      0.4, 0.12, 0.8,
      0.6, 0.5,
      0.03, 0.12,
      0.003,
      pigment { P_IW_01 color_map { CM_IW_25 } scale 0.4 },
      Fin_T3,
      No_Normal
    )

    rotate 90*x
    rotate 5*z
    translate <-0.12, 1.2, 0.3*0.6 >
  }

  object {
    IW_Plank_Round_Cut (
      623,
      0.25, 0.13, 1.4,
      2, 6.5,
      0.006, 0.0045,
      0.03,
      pigment { P_IW_03 color_map { CM_IW_Cherry_03 } scale 0.7 },
      Fin_T3,
      No_Normal
    )

    rotate 90*y
    rotate 60*z
    translate <-1.4, 0.18, 0.25>
  }

#end

// ====================================================

#if (show_Cylinders)

  object {
    IW_Cylinder_Chamfered (
      88,
      0.25, 0.4,
      3.6, 0.2,
      0.03,
      0.004, 0.006,
      pigment { P_IW_11 color_map { CM_IW_09 } scale 0.3 },
      Fin_T,
      No_Normal
    )

    translate <0.6, -0.2, 0.0>
  }

  object {
    IW_Cylinder (
      1188,
      0.12, 0.36,
      3.6, 0.2,
      0.004,
      pigment { P_IW_06 color_map { CM_IW_Pine_02 } scale 0.3 },
      Fin_T,
      No_Normal
    )

    translate <0.82, 0.3, 0.0>
  }

  object {
    IW_Cylinder_Chamfered (
      1898,
      0.07, 0.5,
      3.6, 0.3,
      0.013,
      0.006, 0.007,
      pigment { P_IW_12 color_map { CM_IW_Pine_03 } scale 0.22 },
      Fin_T,
      No_Normal
    )

    rotate 90*y
    rotate 30*z
    translate <0.7, -0.6, 0.07>
  }

  object {
    IW_Cylinder_Chamfered (
      1898,
      0.06, 0.45,
      3.6, 0.4,
      0.013,
      0.006, 0.007,
      pigment { P_IW_12 color_map { CM_IW_Beech_03 } scale 0.22 },
      Fin_T,
      No_Normal
    )

    rotate 90*y
    rotate -10*z
    translate <0.67, -0.75, 0.06>
  }

  object {
    IW_Cylinder_Chamfered (
      4598,
      0.05, 0.45,
      3.6, 0.4,
      0.013,
      0.006, 0.007,
      pigment { P_IW_12 color_map { CM_IW_Oak_03 } scale 0.2 },
      Fin_T,
      No_Normal
    )

    rotate 90*y
    rotate -32*z
    translate <0.4, -0.8, 0.05>
  }

#end

// ====================================================


